..
      Copyright 2012 Nicolas Barcet for Canonical

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

=====================================
Welcome to the Panko's documentation!
=====================================

The Panko project is an event storage service that provides the ability to
store and querying event data generated by Ceilometer with potentially other
sources.

Panko is a component of the Telemetry project.

This documentation offers information on how Panko works and how to
contribute to the project.

Overview
========

.. toctree::
   :maxdepth: 2

   install/index
   contributor/index
   webapi/index

.. update index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
